unit uSpielmanager;

interface

uses uWuerfel, uKonto, uSpielbrett, uGluecksrad, uZufallsgeraet;

type
  TSpielmanager = class
  private
    zustand: integer;
    geraet: TZufallsgeraet;
    wuerfel: TWuerfel;
    rad: TGluecksrad;
    konto: TKonto;
    spielbrett: TSpielbrett;
  public
    constructor create;
    destructor destroy; override;
    procedure einsatzZahlen;
    procedure spielzahlSetzen(z: integer);
    procedure wuerfelWerfen;
    procedure gewinnVerbuchen;
    function getWertA: integer;
    function getWertB: integer;
    function getWertC: integer;
    function getKonto: integer;
    function getZustand: integer;
  end;

implementation

constructor TSpielmanager.create;
begin
  zustand := 0;
  geraet := TZufallsgeraet.create;
  wuerfel := TWuerfel.create;
  rad := TGluecksrad.create;
  konto := TKonto.create(100);
  spielbrett := TSpielbrett.create;
end;

destructor TSpielmanager.destroy;
begin
  geraet.free;
  wuerfel.free;
  rad.free;
  konto.free;
  spielbrett.free;
end;

procedure TSpielmanager.einsatzZahlen;
begin
  if zustand = 0 then
  begin
    konto.abheben(1);
    zustand := 1;
  end;
end;

procedure TSpielmanager.spielzahlSetzen(z: integer);
begin
  if zustand = 1 then
  begin
    spielbrett.setzen(z);
    zustand := 1;
  end;
end;

procedure TSpielmanager.wuerfelWerfen;
begin
  if zustand = 1 then
  begin
    geraet.aktivieren;
    wuerfel.aktivieren;
    rad.aktivieren;
    zustand := 2;
  end;
end;

procedure TSpielmanager.gewinnVerbuchen;
  var richtige, zahl: integer;
begin
  if zustand = 2 then
  begin
    richtige := 0;
    zahl := spielbrett.getZahl;
    if zahl = geraet.getWert then inc(richtige);
    if zahl = wuerfel.getWert then inc(richtige);
    if zahl = rad.getWert then inc(richtige);
    if richtige > 0 then konto.einzahlen(richtige+1);
    zustand := 0;
  end;
end;

function TSpielmanager.getWertA: integer;
begin
  result := geraet.getWert;
end;

function TSpielmanager.getWertB: integer;
begin
  result := wuerfel.getWert;
end;

function TSpielmanager.getWertC: integer;
begin
  result := rad.getWert;
end;

function TSpielmanager.getKonto: integer;
begin
  result := konto.getStand;
end;

function TSpielmanager.getZustand: integer;
begin
  result := zustand;
end;

end.
